#!/usr/bin/env python3
"""
Testing webview library for opening up a native web view as a UI client.
"""
import webview

#webview.create_window("It works, Jim!", "http://www.flowrl.com")
webview.create_window("yo!", "http://alensiljak.ml")
