""" Tests for scheduled transactions script """


def test_creation():
    """ Call the cli and test scheduler tx script """
    from gnucash_portfolio_cli import gpcli
    #gpcli.main("scheduled")
    pass
